SystemOrganization addCategory: #'Seaside-Security'!

!WAKeyGenerator class methodsFor: '*Seaside-Security' stamp: 'pmm 2/8/2014 14:07'!
current: aKeyGenerator
	current := aKeyGenerator! !

!GRPackage class methodsFor: '*seaside-security' stamp: 'pmm 2/8/2014 16:16'!
seasideSecurity
	^ self new
		name: 'Seaside-Security';
		addDependency: 'Seaside-Core';
		url: #seasideUrl;
		yourself! !

WARequestFilter subclass: #WANoSniffFilter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WANoSniffFilter methodsFor: 'processing' stamp: 'pmm 2/6/2014 16:10'!
handleFiltered: aRequestContext
	aRequestContext response noSniff.
	super handleFiltered: aRequestContext! !

WAConfiguredRequestFilter subclass: #WAStrictTransportSecurityFilter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WAStrictTransportSecurityFilter commentStamp: 'pmm 1/23/2011 16:38' prior: 0!
I implement strict transport security (STS) for Seaside. STS tries to prevent users from accidentially using non SSL versions of your application. 
 
http://www.imperialviolet.org/2010/01/26/sts.html
http://lists.w3.org/Archives/Public/www-archive/2009Sep/att-0051/draft-hodges-strict-transport-sec-05.plain.html!

!WAStrictTransportSecurityFilter methodsFor: 'configuration' stamp: 'pmm 1/23/2011 21:13'!
defaultConfiguration
	^ WAUserConfiguration new
		addParent: WAStrictTransportSecurityFilterConfiguration instance;
		yourself! !

!WAStrictTransportSecurityFilter methodsFor: 'processing' stamp: 'pmm 1/23/2011 21:27'!
handleFiltered: aRequestContext
	"Adds a Secure-Transport-Security header in case the application is transmitted over HTTPS."
	
	| request |
	request := aRequestContext request.
	request isSsl
		ifTrue: [
			aRequestContext response strictTransportSecurity: self maxAge includeSubDomains: self includeSubDomains.
			super handleFiltered: aRequestContext ]
		ifFalse: [
			| safeUrl |
			safeUrl := request url copy.
			safeUrl host: request host.
			safeUrl scheme: 'https'.
			aRequestContext redirectTo: safeUrl ]! !

!WAStrictTransportSecurityFilter methodsFor: 'configuration' stamp: 'as 1/22/2011 09:47'!
includeSubDomains
	^ self configuration at: #includeSubDomains! !

!WAStrictTransportSecurityFilter methodsFor: 'configuration' stamp: 'as 1/22/2011 09:47'!
maxAge
	^ self configuration at: #maxAge! !

WASystemConfiguration subclass: #WAStrictTransportSecurityFilterConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Security'!

!WAStrictTransportSecurityFilterConfiguration methodsFor: 'description' stamp: 'pmm 2/9/2014 12:13'!
describeOn: config
	(config integer: #maxAge)
		comment: 'The number of seconds the user agent should remember receipt of this header field from this server.';
		default: 3600 * 24 * 14. "two weeks"
	(config boolean: #includeSubDomains)
		comment: 'If true signals to the user agent that the STS Policy applies to this STS Server as well as any subdomains of the server''s fully qualified domain name.';
		default: false! !

!WAResponse methodsFor: '*seaside-security' stamp: 'pmm 2/6/2014 16:08'!
noSniff
	"trun off content sniffing
	http://blogs.msdn.com/ie/archive/2008/07/02/ie8-security-part-v-comprehensive-protection.aspx
	
	Sending the new X-Content-Type-Options response header with the value nosniff will prevent Internet Explorer from MIME-sniffing a response away from the declared content-type."
	self headerAt: 'X-Content-Type-Options' put: 'nosniff'! !
